// Example mod file to solve DSGE model
// Created by Thomas Drechsel, University of Maryland
// ECON 747, 2023
// Need to fill parts marked with < >

// Variables block 
var y k c z v;
varexo eps_z eps_v;

// Parameters block
parameters bet sig alph del 
           rho_z rho_v sig_z sig_v;

bet = 0.99; % discount factor
sig = 3; % IES
alph = 0.3; % capital share
del = 0.025; % depreciation rate
rho_z = 0.9;
rho_v = 0.9;
sig_z = 0.1;
sig_v = 0.1;

// Model block
model;

% Euler equation
c^(-sig)/v = bet * c(+1)^(-sig) * (z(+1)*alph*k^(alph-1) + (1-del)/v(+1));

% Budget constraint
c + k/v - (1-del)*k(-1)/v = z*k(-1)^alph;

% Production function
y = z*k(-1)^alph;

% Exogenous processes
z = 1-rho_z + rho_z*z(-1) + eps_z;
v = 1-rho_v + rho_v*v(-1) + eps_v;

end;

// Steady state block
steady;

check;

// Shocks block
shocks;
var eps_z; stderr sig_z;
var eps_v; stderr sig_v;
end;

// Solution block 
stoch_simul(order=1,IRF=20) ;